FrameError

Enum FrameError 

pub enum FrameError {
Show 14 variants BadFrameSize, MaxFrameSize, TooMuchPadding, TooManyHeaders(StreamId), InvalidSettingValue, InvalidPayloadLength, InvalidPayloadAckSettings, InvalidStreamId, MalformedMessage, InvalidDependencyId, InvalidPreface, UnexpectedPushPromise, Continuation(FrameContinuationError), Hpack(DecoderError),
}
Errors that can occur during parsing an HTTP/2 frame.

Variants



BadFrameSize

A length value other than 8 was set on a PING message.



MaxFrameSize

Frame size exceeded



TooMuchPadding

The padding length was larger than the frame-header-specified length of the payload.



TooManyHeaders(StreamId)

Headers frame contains too many headers



InvalidSettingValue

An invalid setting value was provided



InvalidPayloadLength

The payload length specified by the frame header was not the value necessary for the specific frame type.



InvalidPayloadAckSettings

Received a payload with an ACK settings frame



InvalidStreamId

An invalid stream identifier was provided.

This is returned if a SETTINGS or PING frame is received with a stream identifier other than zero.



MalformedMessage

A request or response is malformed.



InvalidDependencyId

An invalid stream dependency ID was provided

This is returned if a HEADERS or PRIORITY frame is received with an invalid stream identifier.



InvalidPreface

An invalid preface



UnexpectedPushPromise

Unexpected push promise



Continuation(FrameContinuationError)

Continuation related error



Hpack(DecoderError)

Failed to perform HPACK decoding