Codec

Struct Codec 

pub struct Codec(/* private fields */);

Implementations

Source

impl Codec

pub fn set_recv_frame_size(&self, val: usize)

Updates the max received frame size.

The change takes effect the next time a frame is decoded. In other words, if a frame is currently in process of being decoded with a frame size greater than val but less than the max frame size in effect before calling this function, then the frame will be allowed.

Panics

Panics if size is greater than 16_777_215.

pub fn recv_frame_size(&self) -> u32

Local max frame size.

pub fn set_recv_header_list_size(&self, val: usize)

Set the max header list size that can be received.

By default value is set to 48kb

pub fn set_max_header_continuations(&self, val: usize)

Set the max header continuation frames.

By default value is set to 5

pub fn set_send_frame_size(&self, val: usize)

Set the peer’s max frame size.

Panics

Panics if size is greater than 16_777_215.

pub fn set_send_header_table_size(&self, val: usize)

Set the peer’s header table size size.

pub fn send_frame_size(&self) -> u32

Remote max frame size.